==> haskell-cipher-aes128-0.7.0.6-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cipher-aes128
version:              0.7.0.6
visibility:           public
id:                   cipher-aes128-0.7.0.6-293OA4UWbW1LiO3lrhXQCd
key:                  cipher-aes128-0.7.0.6-293OA4UWbW1LiO3lrhXQCd
license:              BSD-3-Clause
copyright:            Thomas M. DuBuisson
maintainer:           thomas.dubuisson@gmail.com
author:               Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage:             https://github.com/TomMD/cipher-aes128
synopsis:             AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.

category:             Cryptography
abi:                  c35ac17b67edd3c6309559c1ea33c74b
exposed:              True
exposed-modules:      Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cipher-aes128-0.7.0.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cipher-aes128-0.7.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cipher-aes128
hs-libraries:         HScipher-aes128-0.7.0.6-293OA4UWbW1LiO3lrhXQCd
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
    crypto-api-0.13.3-EHPdhbKdFzpJPwJ37IaBSu
    tagged-0.8.7-8MQxDldL1qw9fJF5LZxnpf

haddock-interfaces:
    /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock

haddock-html:         /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes128-0.7.0.6-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cipher-aes128
version:              0.7.0.6
visibility:           public
id:                   cipher-aes128-0.7.0.6-DBAAA18Kt7cIu1qxwlxwQn
key:                  cipher-aes128-0.7.0.6-DBAAA18Kt7cIu1qxwlxwQn
license:              BSD-3-Clause
copyright:            Thomas M. DuBuisson
maintainer:           thomas.dubuisson@gmail.com
author:               Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage:             https://github.com/TomMD/cipher-aes128
synopsis:             AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.

category:             Cryptography
abi:                  ca6c59ee83d1a548810159a7d853088e
exposed:              True
exposed-modules:      Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cipher-aes128-0.7.0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cipher-aes128-0.7.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cipher-aes128
hs-libraries:         HScipher-aes128-0.7.0.6-DBAAA18Kt7cIu1qxwlxwQn
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    crypto-api-0.13.3-95IFBy4WvL6L3p6UFm5MLc
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg

haddock-interfaces:
    /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock

haddock-html:         /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
